# ようこそ!

OpenSesame 3 を初めて利用するようですね。

もしOpenSesameを使用したことがない場合は先に初心者チュートリアルを行うことをおすすめします。少し時間はかかりますが、その後の時間を大幅に節約できます

[チュートリアル](new:http://osdoc.cogsci.nl/3.2/tutorials/beginner){: .important-button}

もし以前に OpenSesame 2 を利用したことがある場合はこのバージョン(バージョン3.2)の変更点をご覧になることをおすすめします。心配しないでください: 古いバージョンで作成した実験は今まで通り動作し、さらに簡単に便利になりました。

[OpenSesame 3 での変更点](new:http://osdoc.cogsci.nl/3.2/important-changes-3){: .button}

そして、いつでもサポートフォーラムで質問することもできます:

[サポートフォーラム](new:http://forum.cogsci.nl/){: .button}

もしくは:

[今後このメッセージを表示しない](opensesame://event.os3n_dismiss_startup){: .dismiss-button}
